@@ -1,5 +1,5 @@
-import { styled } from "@material/ui";
-import s from "styled-components";
+import { styled } from '@material/ui';
+import s from 'styled-components';
 const Paragraph = s.p.withConfig({
     displayName: "code__Paragraph",
     componentId: "sc-c285d12a-0"
